==> fiduswriter-3.9.0rc7.tar.gz: fiduswriter-3.9.0rc7/fiduswriter/document/static/js/modules/editor/state_plugins/index.js <==
export {
    accessRightsPlugin
}
    from "./access_rights"
export {
    contributorInputPlugin,
    ContributorsPartView
}
    from "./contributor_input"
export {
    citationRenderPlugin
}
    from "./citation_render"
export {
    clipboardPlugin
}
    from "./clipboard"
export {
    getSelectionUpdate,
    updateCollaboratorSelection,
    removeCollaboratorSelection,
    collabCaretsPlugin
}
    from "./collab_carets"
export {
    addCommentDuringCreationDecoration,
    removeCommentDuringCreationDecoration,
    getCommentDuringCreationDecoration,
    commentsPlugin
}
    from "./comments"
export {
    documentTemplatePlugin
}
    from "./document_template"
export {
    findFootnoteMarkers,
    getFootnoteMarkerContents,
    updateFootnoteMarker,
    getFootnoteMarkers,
    footnoteMarkersPlugin
}
    from "./footnote_markers"
export {
    headerbarPlugin
}
    from "./headerbar"
export {
    jumpHiddenNodesPlugin
}
    from "./jump_hidden_nodes"
export {
    linksPlugin,
    getInternalTargets
}
    from "./links"
export {
    marginboxesPlugin
}
    from "./marginboxes"
export {
    orderedListMenuPlugin
}
    from "./ordered_list_menu"
export {
    placeholdersPlugin
}
    from "./placeholders"
export {
    selectionMenuPlugin
}
    from "./selection_menu"
export {
    settingsPlugin
}
    from "./settings"
export {
    tablePlugin
}
    from "./table"
export {
    figurePlugin
}
    from "./figure"
export {
    tagInputPlugin,
    TagsPartView
}
    from "./tag_input"
export {
    tocRenderPlugin
}
    from "./toc_render"
export {
    toolbarPlugin
}
    from "./toolbar"
export {
    trackPlugin,
    getSelectedChanges,
    setSelectedChanges,
    deactivateAllSelectedChanges
}
    from "./track"
export {
    searchPlugin,
    setSearchTerm,
    getSearchMatches,
    selectPreviousSearchMatch,
    selectNextSearchMatch,
    deselectSearchMatch,
    endSearch
}
    from "./search"

==> fiduswriter-3.9.3.tar.gz: fiduswriter-3.9.3/fiduswriter/document/static/js/modules/editor/state_plugins/index.js <==
export {
    accessRightsPlugin
}
    from "./access_rights"
export {
    contributorInputPlugin,
    ContributorsPartView
}
    from "./contributor_input"
export {
    citationRenderPlugin
}
    from "./citation_render"
export {
    clipboardPlugin
}
    from "./clipboard"
export {
    getSelectionUpdate,
    updateCollaboratorSelection,
    removeCollaboratorSelection,
    collabCaretsPlugin
}
    from "./collab_carets"
export {
    addCommentDuringCreationDecoration,
    removeCommentDuringCreationDecoration,
    getCommentDuringCreationDecoration,
    commentsPlugin
}
    from "./comments"
export {
    documentTemplatePlugin,
    checkProtectedInSelection
}
    from "./document_template"
export {
    findFootnoteMarkers,
    getFootnoteMarkerContents,
    updateFootnoteMarker,
    getFootnoteMarkers,
    footnoteMarkersPlugin
}
    from "./footnote_markers"
export {
    headerbarPlugin
}
    from "./headerbar"
export {
    jumpHiddenNodesPlugin
}
    from "./jump_hidden_nodes"
export {
    linksPlugin,
    getInternalTargets
}
    from "./links"
export {
    marginboxesPlugin
}
    from "./marginboxes"
export {
    orderedListMenuPlugin
}
    from "./ordered_list_menu"
export {
    placeholdersPlugin
}
    from "./placeholders"
export {
    selectionMenuPlugin
}
    from "./selection_menu"
export {
    settingsPlugin
}
    from "./settings"
export {
    tablePlugin
}
    from "./table"
export {
    figurePlugin
}
    from "./figure"
export {
    tagInputPlugin,
    TagsPartView
}
    from "./tag_input"
export {
    tocRenderPlugin
}
    from "./toc_render"
export {
    toolbarPlugin
}
    from "./toolbar"
export {
    trackPlugin,
    getSelectedChanges,
    setSelectedChanges,
    deactivateAllSelectedChanges
}
    from "./track"
export {
    searchPlugin,
    setSearchTerm,
    getSearchMatches,
    selectPreviousSearchMatch,
    selectNextSearchMatch,
    deselectSearchMatch,
    endSearch
}
    from "./search"
